/**
 * Copyright (c) 2008 Washington University
 */
package org.nrg.xnat.client;

import java.io.IOException;
import java.net.URI;
import java.net.URISyntaxException;

import org.apache.http.HttpEntity;
import org.apache.http.HttpException;
import org.apache.http.HttpResponse;
import org.apache.http.StatusLine;
import org.apache.http.client.HttpClient;
import org.apache.http.client.methods.HttpDelete;
import org.apache.http.client.methods.HttpPost;
import org.apache.http.client.methods.HttpUriRequest;
import org.apache.http.impl.client.DefaultHttpClient;
import org.apache.log4j.BasicConfigurator;

/**
 * Simple client for tag label operations
 * @author Kevin A. Archie <karchie@npg.wustl.edu>
 *
 */
public final class TagClient {
    public enum Operation { DEFINE, DELETE };
    
    public static void request(final Operation op, final URI uri) throws IOException,HttpException {
	final HttpUriRequest request;
	switch (op) {
	case DEFINE: request = new HttpPost(uri); break;
	case DELETE: request = new HttpDelete(uri); break;
	default: throw new IllegalArgumentException("invalid operation: " + op);
	}
	
	final HttpClient client = new DefaultHttpClient();
	final HttpResponse response = client.execute(request);
	final StatusLine status = response.getStatusLine();
	System.out.println("Response " + status);
	final HttpEntity re = response.getEntity();
	re.writeTo(System.out);

    }
    
    /**
     * @param args
     */
    public static void main(String[] args) throws HttpException,IOException,URISyntaxException {
	BasicConfigurator.configure();
	
	if (args.length < 1) {
	    System.out.println("Usage: TagClient <uri> [-delete] [<tag-label> ...]");
	    return;
	}
	
	Operation op = Operation.DEFINE;
	final StringBuilder uri = new StringBuilder(args[0]);
	int i;
	for (i = 1; i < args.length && args[i].startsWith("-"); i++) {
	    if ("-delete".equals(args[i])) {
		if (Operation.DELETE.equals(op)) {
		    throw new IllegalArgumentException("-delete may be specified only once");
		} else {
		    op = Operation.DELETE;
		}
	    }
	}
	
	if (i < args.length) {
	    uri.append("?");
	    uri.append(args[i++]);
	}

	while (i < args.length) {
	    uri.append("&");
	    uri.append(args[i++]);
	}

	request(op, new URI(uri.toString()));
    }
}
